@@ -22,6 +22,21 @@
 #
 # ##### END GPL LICENSE BLOCK #####
 
+bl_addon_info = {
+    "name": "Dynamic Spacebar Menu",
+    "author": "JayDez, sim88, meta-androcto", "sam"
+    "version": (1,5),
+    "blender": (2, 5, 3),
+    "api": 31854,
+    "location": "View3D > Spacebar",
+    "description": "Context sensitive spacebar menu",
+    "warning": "",
+    "wiki_url": "http://wiki.blender.org/index.php/Extensions:2.5/Py/"\
+        "Scripts/3D_interaction/Dynamic_Spacebar_Menu",
+    "tracker_url": "https://projects.blender.org/tracker/index.php?"\
+        "func=detail&aid=22060&group_id=153&atid=469",
+    "category": "3D View"}
+
 """
 Dynamic Menu
 This adds a the Dynamic Spacebar Menu in the View3D.
@@ -47,21 +62,6 @@ v0.1 through 0.9 - various tests/contributions by various people and scripts
     Scripts: 3D Cursor Menu, Original Dynamic Menu
 """
 
-
-bl_addon_info = {
-    'name': '3D View: Dynamic Spacebar Menu',
-    'author': 'JayDez, sim88, meta-androcto', 'sam'
-    'version': '1.5',
-    'blender': (2, 5, 3),
-    'location': 'View3D > Spacebar',
-    'description': 'Context sensitive spacebar menu',
-    'warning': '', # used for warning icon and text in addons panel
-    'wiki_url': 'http://wiki.blender.org/index.php/Extensions:2.5/Py/' \
-        'Scripts/3D_interaction/Dynamic_Spacebar_Menu',
-    'tracker_url': 'https://projects.blender.org/tracker/index.php?'\
-        'func=detail&aid=22060&group_id=153&atid=469',
-    'category': '3D View'}
-
 import bpy
 from bpy import *
 from mathutils import Vector, Matrix
@@ -162,6 +162,10 @@ class VIEW3D_MT_Space_Dynamic_Menu(bpy.types.Menu):
             layout.menu("VIEW3D_MT_edit_TK", icon='OUTLINER_OB_MESH')
             layout.separator()
 
+            # Multi Select
+            layout.menu("VIEW3D_MT_edit_multi", icon='VERTEXSEL')
+            layout.separator()
+            
             # Extrude block
             layout.menu("VIEW3D_MT_edit_mesh_extrude", icon='EDITMODE_HLT')
             layout.separator()
@@ -169,7 +173,7 @@ class VIEW3D_MT_Space_Dynamic_Menu(bpy.types.Menu):
             # Tools block
             layout.menu("VIEW3D_MT_edit_mesh_specials", icon='MODIFIER')
             layout.menu("VIEW3D_MT_uv_map", icon='MOD_UVPROJECT')
-			
+
             # Select block
             layout.menu("VIEW3D_MT_SelectMenu", icon='RESTRICT_SELECT_OFF')
 
@@ -203,8 +207,8 @@ class VIEW3D_MT_Space_Dynamic_Menu(bpy.types.Menu):
             layout.separator()
 
             # Proportional block
-            layout.prop_menu_enum(settings, "proportional_editing", icon= "PROP_CON")
-            layout.prop_menu_enum(settings, "proportional_editing_falloff", icon= "SMOOTHCURVE")
+            layout.prop_menu_enum(settings, "proportional_edit", icon= "PROP_CON")
+            layout.prop_menu_enum(settings, "proportional_edit_falloff", icon= "SMOOTHCURVE")
             layout.separator()
 
             # Edit Control Points
@@ -256,8 +260,8 @@ class VIEW3D_MT_Space_Dynamic_Menu(bpy.types.Menu):
             layout.separator()
 
             # Proportional block
-            layout.prop_menu_enum(settings, "proportional_editing", icon= "PROP_CON")
-            layout.prop_menu_enum(settings, "proportional_editing_falloff", icon= "SMOOTHCURVE")
+            layout.prop_menu_enum(settings, "proportional_edit", icon= "PROP_CON")
+            layout.prop_menu_enum(settings, "proportional_edit_falloff", icon= "SMOOTHCURVE")
 
             # Edit Curve Specials
             layout.menu("VIEW3D_MT_EditCurveSpecials",
@@ -303,8 +307,8 @@ class VIEW3D_MT_Space_Dynamic_Menu(bpy.types.Menu):
             layout.separator()
 
             # Proportional block
-            layout.prop_menu_enum(settings, "proportional_editing", icon= "PROP_CON")
-            layout.prop_menu_enum(settings, "proportional_editing_falloff", icon= "SMOOTHCURVE")
+            layout.prop_menu_enum(settings, "proportional_edit", icon= "PROP_CON")
+            layout.prop_menu_enum(settings, "proportional_edit_falloff", icon= "SMOOTHCURVE")
 
             # Cursor block
             layout.menu("VIEW3D_MT_CursorMenu", icon='CURSOR')
@@ -345,8 +349,8 @@ class VIEW3D_MT_Space_Dynamic_Menu(bpy.types.Menu):
             layout.separator()
 
             # Proportional block
-            layout.prop_menu_enum(settings, "proportional_editing", icon= "PROP_CON")
-            layout.prop_menu_enum(settings, "proportional_editing_falloff", icon= "SMOOTHCURVE")
+            layout.prop_menu_enum(settings, "proportional_edit", icon= "PROP_CON")
+            layout.prop_menu_enum(settings, "proportional_edit_falloff", icon= "SMOOTHCURVE")
 
             # Cursor block
             layout.menu("VIEW3D_MT_CursorMenu", icon='CURSOR')
@@ -391,8 +395,8 @@ class VIEW3D_MT_Space_Dynamic_Menu(bpy.types.Menu):
             layout.separator()
 
             # Proportional block
-            layout.prop_menu_enum(settings, "proportional_editing", icon= "PROP_CON")
-            layout.prop_menu_enum(settings, "proportional_editing_falloff", icon= "SMOOTHCURVE")
+            layout.prop_menu_enum(settings, "proportional_edit", icon= "PROP_CON")
+            layout.prop_menu_enum(settings, "proportional_edit_falloff", icon= "SMOOTHCURVE")
 
             # Cursor block
             layout.menu("VIEW3D_MT_CursorMenu", icon='CURSOR')
@@ -883,7 +887,7 @@ class VIEW3D_MT_SelectEditMenu(bpy.types.Menu):
 
         layout.operator("mesh.select_by_number_vertices", text="Triangles").type = 'TRIANGLES'
         layout.operator("mesh.select_by_number_vertices", text="Quads").type = 'QUADS'
-        if context.scene.tool_settings.mesh_selection_mode[2] == False:
+        if context.scene.tool_settings.mesh_select_mode[2] == False:
                 layout.operator("mesh.select_non_manifold", text="Non Manifold")
         layout.operator("mesh.select_by_number_vertices", text="Loose Verts/Edges").type = 'OTHER'
         layout.operator("mesh.select_similar", text="Similar")
@@ -1074,7 +1078,7 @@ class VIEW3D_MT_SelectMetaball(bpy.types.Menu):
         layout.operator("mball.select_random_metaelems")
 
 class VIEW3D_MT_edit_TK(bpy.types.Menu):
-    bl_label = "Edit Mesh"
+    bl_label = "Edit Mesh Tools"
 
     def draw(self, context):
         layout = self.layout
@@ -1082,29 +1086,54 @@ class VIEW3D_MT_edit_TK(bpy.types.Menu):
 
         layout.operator_context = 'INVOKE_REGION_WIN'
 
-        prop = layout.operator("wm.context_set_value",
-            text="Select By Vertex", icon='VERTEXSEL')
-        prop.value = "(True, False, False)"
-        prop.data_path = "tool_settings.mesh_selection_mode"
         layout.menu("VIEW3D_MT_edit_mesh_vertices", icon='VERTEXSEL')
-
-        prop = layout.operator("wm.context_set_value",
-            text="Select By Edge", icon='EDGESEL')
-        prop.value = "(False, True, False)"
-        prop.data_path = "tool_settings.mesh_selection_mode"
         layout.menu("VIEW3D_MT_edit_mesh_edges", icon='EDGESEL')
-
-        prop = layout.operator("wm.context_set_value",
-            text="Select By Face", icon='FACESEL')
-        prop.value = "(False, False, True)"
-        prop.data_path = "tool_settings.mesh_selection_mode"
         layout.menu("VIEW3D_MT_edit_mesh_faces", icon='FACESEL')
         layout.separator()
-
         layout.menu("VIEW3D_MT_edit_mesh_normals", icon='META_DATA')
         layout.operator("mesh.loopcut_slide",
             text="Loopcut", icon='EDIT_VEC')
 
+
+
+class VIEW3D_MT_edit_multi(bpy.types.Menu):
+    bl_label = "Multi Select"
+
+    def draw(self, context):
+        layout = self.layout
+        layout.operator_context = 'INVOKE_REGION_WIN'
+
+        layout.separator()
+        prop = layout.operator("wm.context_set_value", text="Vertex Select", icon='VERTEXSEL')
+        prop.value = "(True, False, False)"
+        prop.data_path = "tool_settings.mesh_select_mode"
+
+        prop = layout.operator("wm.context_set_value", text="Edge Select", icon='EDGESEL')
+        prop.value = "(False, True, False)"
+        prop.data_path = "tool_settings.mesh_select_mode"
+
+        prop = layout.operator("wm.context_set_value", text="Face Select", icon='FACESEL')
+        prop.value = "(False, False, True)"
+        prop.data_path = "tool_settings.mesh_select_mode"
+        layout.separator()
+
+        prop = layout.operator("wm.context_set_value", text="Vertex & Edge Select", icon='EDITMODE_HLT')
+        prop.value = "(True, True, False)"
+        prop.data_path = "tool_settings.mesh_select_mode"
+
+        prop = layout.operator("wm.context_set_value", text="Vertex & Face Select", icon='ORTHO')
+        prop.value = "(True, False, True)"
+        prop.data_path = "tool_settings.mesh_select_mode"
+
+        prop = layout.operator("wm.context_set_value", text="Edge & Face Select", icon='SNAP_FACE')
+        prop.value = "(False, True, True)"
+        prop.data_path = "tool_settings.mesh_select_mode"
+        layout.separator()
+
+        prop = layout.operator("wm.context_set_value", text="Vertex & Edge & Face Select", icon='SNAP_VOLUME')
+        prop.value = "(True, True, True)"
+        prop.data_path = "tool_settings.mesh_select_mode"
+
 class VIEW3D_MT_editM_Edge(bpy.types.Menu):
     bl_label = "Edges"
 
@@ -1241,7 +1270,8 @@ class VIEW3D_OT_pivot_cursor(bpy.types.Operator):
     bl_idname = "view3d.pivot_cursor"
     bl_label = "Cursor as Pivot Point"
 
-    def poll(self, context):
+    @classmethod
+    def poll(cls, context):
         return bpy.context.space_data.pivot_point != 'CURSOR'
 
     def execute(self, context):
@@ -1253,7 +1283,8 @@ class VIEW3D_OT_revert_pivot(bpy.types.Operator):
     bl_idname = "view3d.revert_pivot"
     bl_label = "Reverts Pivot Point to median"
 
-    def poll(self, context):
+    @classmethod
+    def poll(cls, context):
         return bpy.context.space_data.pivot_point != 'MEDIAN_POINT'
 
     def execute(self, context):
@@ -1367,7 +1398,7 @@ def edgeIntersect(context, operator):
     
     edges = [];
     mesh = obj.data
-    verts = mesh.verts
+    verts = mesh.vertices
 
     is_editmode = (obj.mode == 'EDIT')
     if is_editmode:
@@ -1384,7 +1415,7 @@ def edgeIntersect(context, operator):
         operator.report({'ERROR'}, "Operator requires exactly 2 edges to be selected.")
         return
         
-    line = LineLineIntersect(verts[edges[0].verts[0]].co, verts[edges[0].verts[1]].co, verts[edges[1].verts[0]].co, verts[edges[1].verts[1]].co)
+    line = LineLineIntersect(verts[edges[0].vertices[0]].co, verts[edges[0].vertices[1]].co, verts[edges[1].vertices[0]].co, verts[edges[1].vertices[1]].co)
 
     if (line == None):
         operator.report({'ERROR'}, "Selected edges are parallel.")
@@ -1404,7 +1435,8 @@ class VIEW3D_OT_CursorToEdgeIntersection(bpy.types.Operator):
     bl_idname = "view3d.snap_cursor_to_edge_intersection"
     bl_label = "Cursor to Edge Intersection"
 
-    def poll(self, context):
+    @classmethod
+    def poll(cls, context):
         obj = context.active_object
         return obj != None and obj.type == 'MESH'
 
@@ -1422,79 +1454,17 @@ class VIEW3D_MT_undoS(bpy.types.Menu):
         layout.operator("ed.redo", icon='TRIA_RIGHT')
 
 def register():
-    bpy.types.register(VIEW3D_MT_Space_Dynamic_Menu)
-    bpy.types.register(VIEW3D_MT_AddMenu)
-    bpy.types.register(VIEW3D_MT_TransformMenu)
-    bpy.types.register(VIEW3D_MT_MirrorMenu)
-    bpy.types.register(VIEW3D_MT_ParentMenu)
-    bpy.types.register(VIEW3D_MT_GroupMenu)
-    bpy.types.register(VIEW3D_MT_AlignMenu)
-    bpy.types.register(VIEW3D_MT_SelectMenu)
-    bpy.types.register(VIEW3D_MT_SelectEditMenu)
-    bpy.types.register(VIEW3D_MT_SelectCurveMenu)
-    bpy.types.register(VIEW3D_MT_SelectPoseMenu)
-    bpy.types.register(VIEW3D_MT_PoseCopy)
-    bpy.types.register(VIEW3D_MT_PoseNames)
-    bpy.types.register(VIEW3D_MT_KeyframeMenu)
-    bpy.types.register(VIEW3D_MT_SelectArmatureMenu)
-    bpy.types.register(VIEW3D_MT_ArmatureName)
-    bpy.types.register(VIEW3D_MT_SelectMetaball)
-    bpy.types.register(VIEW3D_MT_SelectSurface)
-    bpy.types.register(VIEW3D_MT_edit_TK)
-    bpy.types.register(VIEW3D_MT_EditArmatureTK)
-    bpy.types.register(VIEW3D_MT_editM_Edge)
-    bpy.types.register(VIEW3D_MT_EditCurveCtrlpoints)
-    bpy.types.register(VIEW3D_MT_EditCurveSegments)
-    bpy.types.register(VIEW3D_MT_EditCurveSpecials)
-    bpy.types.register(VIEW3D_OT_pivot_cursor)
-    bpy.types.register(VIEW3D_OT_revert_pivot)
-    bpy.types.register(VIEW3D_MT_CursorMenu)
-    bpy.types.register(VIEW3D_MT_EditCursorMenu)
-    bpy.types.register(VIEW3D_OT_CursorToEdgeIntersection)
-    bpy.types.register(VIEW3D_MT_undoS)
-
-    km = bpy.context.manager.active_keyconfig.keymaps['3D View']
-    kmi = km.items.add('wm.call_menu', 'SPACE', 'PRESS')
+    km = bpy.context.window_manager.keyconfigs.active.keymaps['3D View']
+    kmi = km.items.new('wm.call_menu', 'SPACE', 'PRESS')
     kmi.properties.name = "VIEW3D_MT_Space_Dynamic_Menu"
 
 
 def unregister():
-    bpy.types.unregister(VIEW3D_MT_Space_Dynamic_Menu)
-    bpy.types.unregister(VIEW3D_MT_AddMenu)
-    bpy.types.unregister(VIEW3D_MT_TransformMenu)
-    bpy.types.unregister(VIEW3D_MT_MirrorMenu)
-    bpy.types.unregister(VIEW3D_MT_ParentMenu)
-    bpy.types.unregister(VIEW3D_MT_GroupMenu)
-    bpy.types.unregister(VIEW3D_MT_AlignMenu)
-    bpy.types.unregister(VIEW3D_MT_SelectMenu)
-    bpy.types.unregister(VIEW3D_MT_SelectEditMenu)
-    bpy.types.unregister(VIEW3D_MT_SelectCurveMenu)
-    bpy.types.unregister(VIEW3D_MT_SelectPoseMenu)
-    bpy.types.unregister(VIEW3D_MT_PoseCopy)
-    bpy.types.unregister(VIEW3D_MT_PoseNames)
-    bpy.types.unregister(VIEW3D_MT_KeyframeMenu)
-    bpy.types.unregister(VIEW3D_MT_SelectArmatureMenu)
-    bpy.types.unregister(VIEW3D_MT_ArmatureName)
-    bpy.types.unregister(VIEW3D_MT_SelectMetaball)
-    bpy.types.unregister(VIEW3D_MT_SelectSurface)
-    bpy.types.unregister(VIEW3D_MT_edit_TK)
-    bpy.types.unregister(VIEW3D_MT_EditArmatureTK)
-    bpy.types.unregister(VIEW3D_MT_editM_Edge)
-    bpy.types.unregister(VIEW3D_MT_EditCurveCtrlpoints)
-    bpy.types.unregister(VIEW3D_MT_EditCurveSegments)
-    bpy.types.unregister(VIEW3D_MT_EditCurveSpecials)
-    bpy.types.unregister(VIEW3D_OT_pivot_cursor)
-    bpy.types.unregister(VIEW3D_OT_revert_pivot)
-    bpy.types.unregister(VIEW3D_MT_CursorMenu)
-    bpy.types.unregister(VIEW3D_MT_EditCursorMenu)
-    bpy.types.unregister(VIEW3D_OT_CursorToEdgeIntersection)
-    bpy.types.unregister(VIEW3D_MT_undoS)
-
-    km = bpy.context.manager.active_keyconfig.keymaps['3D View']
+    km = bpy.context.window_manager.keyconfigs.active.keymaps['3D View']
     for kmi in km.items:
         if kmi.idname == 'wm.call_menu':
             if kmi.properties.name == "VIEW3D_MT_Space_Dynamic_Menu":
-                km.remove_item(kmi)
+                km.items.remove(kmi)
                 break
 
 if __name__ == "__main__":
